@@ -27,17 +27,14 @@
 
 #include <QListView>
 
-namespace KontactInterface
-{
+namespace KontactInterface {
 class Core;
 class Plugin;
 }
 
 class QAction;
 
-namespace Kontact
-{
-
+namespace Kontact {
 class Model;
 class MainWindow;
 class Navigator;
@@ -132,7 +129,6 @@ protected:
 private:
     Navigator *mNavigator = nullptr;
 };
-
 }
 
 #endif
