@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,16 +22,14 @@
 
 #include <ksettings/Dialog>
 
-namespace Kontact
-{
-
+namespace Kontact {
 class KontactConfigureDialog : public KSettings::Dialog
 {
     Q_OBJECT
 
 public:
     explicit KontactConfigureDialog(QWidget *parent = nullptr);
-    ~KontactConfigureDialog();
+    ~KontactConfigureDialog() override;
 
 protected:
     QSize sizeHint() const override;
@@ -43,10 +41,7 @@ protected Q_SLOTS:
     /** @reimplemented */
     void slotOk();
     void emitConfigChanged();
-
 };
-
 }
 
 #endif /* KONTACTCONFIGUREDIALOG_H */
-
